===============================
Cointrader
===============================


.. image:: https://img.shields.io/pypi/v/cointrader.svg
        :target: https://pypi.python.org/pypi/cointrader

.. image:: https://img.shields.io/travis/toirl/cointrader.svg
        :target: https://travis-ci.org/toirl/cointrader

.. image:: https://api.codacy.com/project/badge/Grade/ef487c2c01d4491e91dec5b8490214ee
        :target: https://www.codacy.com/app/torsten/cointrader?utm_source=github.com&amp;utm_medium=referral&amp;utm_content=toirl/cointrader&amp;utm_campaign=Badge_Grade

.. image:: https://readthedocs.org/projects/cointrader/badge/?version=latest
        :target: https://cointrader.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status

.. image:: https://pyup.io/repos/github/toirl/cointrader/shield.svg
     :target: https://pyup.io/repos/github/toirl/cointrader/
     :alt: Updates


Cointrader is Python based CLI trading application for crypto currencies on the Poloniex_ exchange.
Cointrader can be used for semiautomatic guided trading.

* Free software: MIT license
* Documentation: https://cointrader.readthedocs.io.


Features
--------

* Explore exchange for interesting markets to trade on
* Show you balances on the exchange
* Semiautomatic trading using a simple trend following strategy

Planned
-------

* Risk- and Money management
 
 * Stop loss limits
 * Take profit limits

* Trade logbook, Profit/Loss analysis
* Full automatic trading
* Pluggable external trading strategies
* Support more exchanges

Motivation
----------
I wrote this application to learn more about how trading can be automated by
doing simple technical analysis on charts. I stuck my nose into trading and
technical analysis in 2017.
I started to read book as trading in general and specialized myself on the
analysis part. As I am a professional programmer doing Python programming for
about 10 years it was natural to me to write such a program.

Credits
---------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Poloniex: https://poloniex.com
.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage

